@@ -215,7 +215,7 @@ void KMixDockWidget::updatePixmap()
 	shared_ptr<MixDevice> md = Mixer::getGlobalMasterMD();
 
     char newPixmapType;
-    if ( md == 0 )
+    if ( !md )
     {
         newPixmapType = 'e';
     }
@@ -405,7 +405,7 @@ void KMixDockWidget::contextMenuAboutToShow()
 void KMixDockWidget::updateDockMuteAction ( KToggleAction* dockMuteAction )
 {  
     shared_ptr<MixDevice> md = Mixer::getGlobalMasterMD();
-    if ( md != 0 && dockMuteAction != 0 )
+    if ( md && dockMuteAction != 0 )
     {
     	Volume& vol = md->playbackVolume().hasVolume() ? md->playbackVolume() : md->captureVolume();
     	bool isInactive =  vol.isCapture() ? !md->isRecSource() : md->isMuted();
